@@ -133,7 +133,7 @@ int             islistgf2();
 #define putmagf2(G, M, VL)              fputma(M, stdout, fputgf2el, 2, G, VL)
 #define fputmagf2(G, M, VL, pf)         fputma(M, pf, fputgf2el, 2, G, VL) 
 #define magf2sum(G, M, N)               masum(M, N, gf2sumf, 1, G)
-#define magf2dif(G, M, N)               magf2sum(M, N, G)
+#define magf2dif(G, M, N)               magf2sum(G, M, N)
 #define magf2prod(G, M, N)              maprod(M, N, gf2prod, gf2sumf, 1, G)
 #define magf2neg(G, M)                  (M)
 #define isvecgf2(G, V)                  (islistgf2(G, V) && V!=_0)
