@@ -81,8 +81,8 @@ int             pvinsert();
 #define marfrprod(r,M, N)  		maprod(M, N,rfrprod,rfrsum,1,r,0)
 #define marfmsp1prod(p,M, N)  		maprod(M, N,rfmsp1prod,rfmsp1sum,1,p,0)
 
-#define marfrcons1(r, N)  		maconsdiag(n,rtorfr(r,itor(1)))
-#define marfmsp1c1(p, N)  		(MADUMMY=list2(0,1), maconsdiag(n,list2(MADUMMY,MADUMMY)))
+#define marfrcons1(r, N)  		maconsdiag(N,rtorfr(r,itor(1)))
+#define marfmsp1c1(p, N)  		(MADUMMY=list2(0,1), maconsdiag(N,list2(MADUMMY,MADUMMY)))
 
 #define marfrvecmul(r,A,x)  		mavecmul(A,x,rfrprod,rfrsum,1,r,0)
 #define marfmsp1vmul(p,A,x)  		mavecmul(A,x,rfmsp1prod,rfmsp1sum,1,p,0)
@@ -170,7 +170,7 @@ int             pvinsert();
 #define putmapgf2(r, M, G, VL, Vgf2)    fputmapgf2(r, M, G, VL, Vgf2, stdout)
 #define fputmapgf2(r, M, G, VL, Vgf2, pf) fputmaspec(M, pf, fputpgf2, 4, r, G, VL, Vgf2, 0, 0, 0, 0)
 #define mapgf2sum(r, G, M, N)           masumspec(M, N, pgf2sum, 2, r, G, 0, 0)
-#define mapgf2dif(r, G, M, N)           mapgf2sum(r, p, G, M, N)
+#define mapgf2dif(r, G, M, N)           mapgf2sum(r, G, M, N)
 #define mapgf2prod(r, G, M, N)          maprodspec(M, N, pgf2prod, pgf2sum, 2, r, G, 0, 0, 0)
 #define mapgf2neg(r, G, M)              (M)
 #define isvecpgf2(r, G, V)              isvecspec_(V, ispgf2, 2, r, G, 0, 0, 0)
@@ -178,7 +178,7 @@ int             pvinsert();
 #define fgetvpgf2(r, G, VL, Vgf2, pf)   fgetvecspec(pf, fgetpgf2, 4, r, G, VL, Vgf2, 0, 0, 0, 0)
 #define putvpgf2(r, G, V, VL, Vgf2)     fputvpgf2(r, G, V, VL, Vgf2, stdout)
 #define fputvpgf2(r, G, V, VL, Vgf2, pf) fputvecspec(V, pf, fputpgf2, 4, r, G, VL, Vgf2, 0, 0, 0, 0)
-#define vecpgf2sum(r, G, U, V)          vecsumspec(U, V, pgf2sum, 2, r, AL, 0, 0, 0)
+#define vecpgf2sum(r, G, U, V)          vecsumspec(U, V, pgf2sum, 2, r, G, 0, 0, 0)
 #define vecpgf2neg(r, G, V)             (V)
 #define vecpgf2dif(r, G, U, V)          vecpgf2sum(r, G, U, V)
 #define mapgf2vmul(r, G, M, V)          mavmulspec(M, V, pgf2prod, pgf2sum, 2, r, G, 0, 0, 0)
